@@ -1,4 +1,4 @@
-from .player import Player
+from .player import Player, BATTLE_MOUNTS, Role
 from collections import Counter, defaultdict
 import pickle
 
@@ -52,9 +52,16 @@ class BattleStat: # Need to handle n team
         
     def addEquipments(self, playerData:dict):
         try:
-            if(playerData['Name'] in self.equipments) and (playerData['Equipment']['MainHand'] is 'None'):
-                continue
-            self.equipments[playerData['Name']] = Player(playerData['Name'], playerData['Equipment']['MainHand'], playerData['AverageItemPower'], playerData['GuildName'], playerData['AllianceName'] )
+            if((playerData['Equipment']['Mount']) and (playerData['Equipment']['Mount']['Type'] in BATTLE_MOUNTS)):
+                weapon = {'Type':"BATTLE_MOUNTS"}
+            elif (playerData['Name'] in self.equipments) and (playerData['Equipment']['MainHand'] is None):
+                return
+            elif (playerData['Name'] in self.equipments) and (self.equipments[playerData['Name']].getType() == Role.BATTLE_MOUNTS):
+                return
+            else:
+                weapon = playerData['Equipment']['MainHand']
+
+            self.equipments[playerData['Name']] = Player(playerData['Name'], weapon, playerData['AverageItemPower'], playerData['GuildName'], playerData['AllianceName'] )
         except:
             print("Error in addEquipments: "+ str(playerData))
             
