@@ -13,13 +13,23 @@ SUPPORT_WEAPON = ['COMBATSTAFF', 'ARCANE', 'CURSEDSTAFF', 'ENIGMATICSTAFF',
                   'DEMONICSTAFF', 'ENIGMATICORB','ICEGAUNTLETS',
                   'DOUBLEBLADEDSTAFF', 'QUARTERSTAFF', 'SHAPESHIFTER_SET2']
 
+
+BATTLE_MOUNTS = {"T8_MOUNT_MAMMOTH_BATTLE@1","T7_MOUNT_SWAMPDRAGON_BATTLE","T7_MOUNT_ARMORED_SWAMPDRAGON_BATTLE","T6_MOUNT_SIEGE_BALLISTA",
+"T6_MOUNT_SIEGE_BALLISTA","UNIQUE_MOUNT_RHINO_SEASON_CRYSTAL","UNIQUE_MOUNT_RHINO_SEASON_GOLD","UNIQUE_MOUNT_RHINO_SEASON_SILVER","UNIQUE_MOUNT_RHINO_SEASON_BRONZE",
+"UNIQUE_MOUNT_TOWER_CHARIOT_CRYSTAL","UNIQUE_MOUNT_TOWER_CHARIOT_GOLD","UNIQUE_MOUNT_TOWER_CHARIOT_SILVER","UNIQUE_MOUNT_ARMORED_EAGLE_CRYSTAL","UNIQUE_MOUNT_ARMORED_EAGLE_GOLD",
+"UNIQUE_MOUNT_ARMORED_EAGLE_SILVER","UNIQUE_MOUNT_BEETLE_CRYSTAL","UNIQUE_MOUNT_BEETLE_GOLD","UNIQUE_MOUNT_BEETLE_SILVER","UNIQUE_MOUNT_BEHEMOTH_CRYSTAL","UNIQUE_MOUNT_BEHEMOTH_GOLD",
+"UNIQUE_MOUNT_BEHEMOTH_SILVER","UNIQUE_MOUNT_ENT_CRYSTAL","UNIQUE_MOUNT_ENT_GOLD","UNIQUE_MOUNT_ENT_SILVER","UNIQUE_MOUNT_BATTLESPIDER_CRYSTAL",
+"UNIQUE_MOUNT_BATTLESPIDER_GOLD","UNIQUE_MOUNT_BATTLESPIDER_SILVER","UNIQUE_MOUNT_BASTION_CRYSTAL","UNIQUE_MOUNT_BASTION_GOLD","UNIQUE_MOUNT_BASTION_SILVER",
+"UNIQUE_MOUNT_JUGGERNAUT_CRYSTAL","UNIQUE_MOUNT_JUGGERNAUT_GOLD","UNIQUE_MOUNT_JUGGERNAUT_SILVER","UNIQUE_MOUNT_TANKBEETLE_CRYSTAL","UNIQUE_MOUNT_TANKBEETLE_GOLD",
+"UNIQUE_MOUNT_TANKBEETLE_SILVER"}
+
 class Role(Enum):
     HEAL = 1
     DPS = 2
     TANK = 3
     SUPPORT = 4
-    OTHER = 5
-    
+    BATTLE_MOUNTS = 5
+    OTHER = 6
 
 class Player:
     def __init__(self, name: str, weapon: dict, ip : float, guildName = None, allianceName = None):
@@ -35,7 +45,9 @@ class Player:
     
     def getType(self):
         weapon_name = self.getWeaponName()
-        if any(weapon in weapon_name for weapon in HEAL_WEAPON):
+        if(weapon_name== "BATTLE_MOUNTS"):
+            return Role.BATTLE_MOUNTS
+        elif any(weapon in weapon_name for weapon in HEAL_WEAPON):
             return Role.HEAL
         elif any(weapon in weapon_name for weapon in TANK_WEAPON):
             return Role.TANK
@@ -47,6 +59,8 @@ class Player:
             return Role.OTHER
 
     def getWeaponName(self):
+        if(self.weaponFullName == "BATTLE_MOUNTS"):
+            return self.weaponFullName
         splitStr = self.weaponFullName.split("_")
         if len(splitStr)>=3:
             weapon = splitStr[2].split('@')[0]
